==> thunderbird-debug-148.0-1-x86_64.pkg.tar.zst: usr/src/debug/thunderbird/thunderbird-148.0/obj-x86_64-pc-linux-gnu/widget/Unified_cpp_widget4.cpp <==
#define MOZ_UNIFIED_BUILD
#include "/build/thunderbird/src/thunderbird-148.0/widget/nsPrinterListCUPS.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsPrinterListCUPS.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsPrinterListCUPS.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/widget/nsTransferable.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsTransferable.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsTransferable.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/widget/nsUserIdleService.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsUserIdleService.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsUserIdleService.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/widget/nsXPLookAndFeel.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsXPLookAndFeel.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsXPLookAndFeel.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/HeadlessWidgetTypes.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/HeadlessWidgetTypes.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/HeadlessWidgetTypes.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/LookAndFeelTypes.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/LookAndFeelTypes.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/LookAndFeelTypes.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysis.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysis.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysis.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisChild.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisChild.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisChild.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisParent.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisParent.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisParent.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequest.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequest.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequest.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestChild.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestChild.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestChild.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestParent.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestParent.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestParent.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequest.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequest.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequest.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestChild.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestChild.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestChild.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestParent.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestParent.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestParent.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidget.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidget.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidget.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif

==> thunderbird-debug-148.0-2-x86_64.pkg.tar.zst: usr/src/debug/thunderbird/thunderbird-148.0/obj-x86_64-pc-linux-gnu/widget/Unified_cpp_widget4.cpp <==
#define MOZ_UNIFIED_BUILD
#include "/build/thunderbird/src/thunderbird-148.0/widget/nsTransferable.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsTransferable.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsTransferable.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/widget/nsUserIdleService.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsUserIdleService.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsUserIdleService.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/widget/nsXPLookAndFeel.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsXPLookAndFeel.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/widget/nsXPLookAndFeel.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/HeadlessWidgetTypes.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/HeadlessWidgetTypes.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/HeadlessWidgetTypes.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/LookAndFeelTypes.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/LookAndFeelTypes.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/LookAndFeelTypes.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysis.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysis.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysis.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisChild.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisChild.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisChild.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisParent.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisParent.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardContentAnalysisParent.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequest.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequest.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequest.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestChild.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestChild.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestChild.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestParent.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestParent.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardReadRequestParent.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequest.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequest.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequest.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestChild.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestChild.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestChild.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestParent.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestParent.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PClipboardWriteRequestParent.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidget.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidget.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidget.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
#include "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidgetChild.cpp"
#ifdef PL_ARENA_CONST_ALIGN_MASK
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidgetChild.cpp uses PL_ARENA_CONST_ALIGN_MASK, so it cannot be built in unified mode."
#undef PL_ARENA_CONST_ALIGN_MASK
#endif
#ifdef INITGUID
#error "/build/thunderbird/src/thunderbird-148.0/obj-x86_64-pc-linux-gnu/ipc/ipdl/PCompositorWidgetChild.cpp defines INITGUID, so it cannot be built in unified mode."
#undef INITGUID
#endif
